package com.kupal.commons.cdm;

import java.beans.PropertyChangeListener;

/**
 * Represents an object with property listener support
 * 
 * @author Kupal
 *         Date: 28.06.2010
 *         Time: 17:27:24
 */
public interface ListenableObject {

    /**
	 * Add a listener to this bean.
	 * @param listener the property change listener to add
	 */
	void addPropertyChangeListener(final PropertyChangeListener listener);

	/**
	 * Add a listener to this bean for a specific property.
	 * @param propertyName the name of the property to listen for changes on
	 * @param listener the property change listener to add
	 */
	void addPropertyChangeListener(final String propertyName, final PropertyChangeListener listener);

	/**
	 * Remove a listener from this bean.
	 * @param listener the property change listener to remove
	 */
	void removePropertyChangeListener(final PropertyChangeListener listener);

	/**
	 * Remove a listener from this bean for a specific property.
	 * @param propertyName the name of the property to stop listening on
	 * @param listener the property change listener to remove
	 */
	void removePropertyChangeListener(final String propertyName, final PropertyChangeListener listener);
}
